/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |                     (DATASET 0002:  INTAKE 2 DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0002-statasetup.do)
 |
 **************************************************************************/

set mem 30m  /* Allocating 30 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0002"

#delimit ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       3 "METHADONE MAINTENANCE" 4 "OUTPATIENT DRUG FREE" ;
label define FORM      1 "NOV91" 2 "OCT92" ;
label define CDC_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define CDC_Y     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CT_L_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONE-FAMILY HOUSE/DUPLEX/CONDO"
                       2 "MOBILE HOME/TRAILER"
                       3 "APT/MULTIPLE FAMILY BUILDING"
                       4 "HOTEL/ROOMING/BOARDING HOUSE"
                       5 "HOSPITAL/MEDICAL INSTITUTION"
                       6 "JAIL/PRISON/JUVENILE DETEN HOME"
                       7 "RESIDENTIAL DRUG TX PROG"
                       8 "OTHER GRP RES/HALFWAY HOUSE" 9 "HOMELESS SHELTER"
                       10 "ON THE STREET" 11 "OTHER" ;
label define CA4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY DISSATISFIED"
                       2 "SOMEWHAT DISSATISFIED" 3 "SOMEWHAT SATISFIED"
                       4 "VERY SATISFIED" ;
label define CA5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA6_WKS   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA7_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA7_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA7_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MARRIED"
                       2 "LEGALLY SEPARATED" 3 "DIVORCED" 4 "WIDOWED"
                       5 "LIVING W/ONE AS MARRIED" 6 "NEVER MARRIED" ;
label define CA10_WKS  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA10_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA10_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT GETTING ALONG"
                       2 "OTHER REASONS" ;
label define CA10_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY MUCH OPPOSED"
                       2 "SOMEWHAT OPPOSED" 3 "DIDNT CARE ONE WAY/OTHER"
                       4 "APPROVED YOUR USE OF DRUGS"
                       5 "WAS NOT AWARE OF YOUR DRUG USE"
                       6 "NOT IN CONTACT WITH PARTNER" ;
label define CA11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY IMPORTANT" ;
label define CA11_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA11_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA11_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA11_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define CA13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "4+" ;
label define CA13_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "0 MOS" 1 "1-12 MOS"
                       2 "13-24 MOS" 3 "25-36 MOS" 4 "37-48 MOS"
                       5 "49-60 MOS" 6 "61-72 MOS" 7 "73-84 MOS"
                       8 "85-96 MOS" 9 "97-108 MOS" 10 "109-120 MOS"
                       11 "121-132 MOS" 12 "133-144 MOS" 13 "145-156 MOS"
                       14 "157-168 MOS" 15 "169-180 MOS" 16 "181-192 MOS"
                       17 "193-204 MOS" 18 "205-216 MOS" 19 "217-228 MOS"
                       20 "229-240 MOS" 21 "241+ MOS" ;
label define CA13_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "4+" ;
label define CA13_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA14_WKS  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA15_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA15_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA16_WKS  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA16_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA16_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA16_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA17_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA17_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA17_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define CA19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA19_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA20_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA20_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA20_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "FELT BAD ABOUT SOME, NOT OTHERS" ;
label define CA20_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define CA21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA21_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA21B_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "6+" ;
label define CA21B_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA21B_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA21B_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "6+" ;
label define CA22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY DISSATISFIED"
                       2 "SOMEWHAT DISSATISFIED" 3 "SOMEWHAT SATISFIED"
                       4 "VERY SATISFIED" ;
label define CA23_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CA23_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA23_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA23_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CA23_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define CA23_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CA24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define CA25_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA25_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA25_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA25_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA25_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define CA26      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "W/SPOUSE/SEXUAL PARTNER/CHILDREN"
                       2 "W/SPOUSE/SEXUAL PARTNER, ONLY"
                       3 "WITH CHILDREN ONLY" 4 "WITH BOTH PARENTS"
                       5 "WITH MOTHER ONLY" 6 "WITH FATHER ONLY"
                       7 "PARENT(S) AND OWN CHILDREN"
                       8 "W/OTHER FAMILY/COMBI 01-07" 9 "WITH FOSTER PARENTS"
                       10 "W/FAMILY/FRIENDS/BOARDERS/ROOMMATE"
                       11 "W/FRIENDS/ROOMMATES ONLY" 12 "ALONE"
                       13 "INSTITUTION/CLOSED FACILITY"
                       14 "NO STABLE ARRANGEMENTS" 15 "OTHER" ;
label define CA27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA27_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA28_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "8+" ;
label define CA30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA30_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA31      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA32      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA32YN    1 "YES" 2 "NO" ;
label define CA32A_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA32A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA32A_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA32A_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CA32A_05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define CA32A_06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CA33      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "7+" ;
label define CA33YN    1 "YES" 2 "NO" ;
label define CA33A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA33A_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA33A_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CA33A_05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define CA33A_06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CA34_0    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define CA34_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CA34_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA34_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA35      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "SOMEWHAT/MAYBE" ;
label define CA36      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA36_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA37_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA37_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA37_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA37_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "AT LEAST ONCE/WK" 4 "ALMOST DAILY" ;
label define CA38      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define CA39      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY DIFFICULT" ;
label define CA40      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "VOL: NEVER LIVED W/CHILD" ;
label define CA41      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA42      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA43      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA44      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "VOL: ONLY WHEN NO INCOME" ;
label define CA45_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA45_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA45A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA45_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA45_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA46      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA46_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA46_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA46_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA46_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA46_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA47      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA47_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY MUCH" ;
label define CA48      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define CA49      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME" 2 "A LOT"
                       93 "IF VOL: NO FAMILY/FRIEND" ;
label define CA50      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER/RARELY"
                       2 "SOME OF THE TIME" 3 "ALMOST ALWAYS" ;
label define CA51      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER/RARELY"
                       2 "SOME OF THE TIME" 3 "ALMOST ALWAYS" ;
label define CA52      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER/RARELY"
                       2 "SOME OF THE TIME" 3 "ALMOST ALWAYS" ;
label define CA53      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER/RARELY"
                       2 "SOME OF THE TIME" 3 "ALMOST ALWAYS" ;
label define CA54      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER/RARELY"
                       2 "SOME OF THE TIME" 3 "ALMOST ALWAYS" ;
label define CA55      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define CA56_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "ONCE/WK" 4 "ALMOST DAILY" ;
label define CA56_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "ONCE/WK" 4 "ALMOST DAILY" ;
label define CA56_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "< ONCE/WK"
                       3 "ONCE/WK" 4 "ALMOST DAILY" ;
label define CA57_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA57_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA57_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA57_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA57_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA57_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define CA58      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY UNHAPPY"
                       2 "SOMEWHAT UNHAPPY" 3 "SOMEWHAT HAPPY" 4 "VERY HAPPY" ;
label define CA59      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WORSE" 2 "BETTER" ;
label define CA60      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA61      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA61_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA61_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA61_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA62      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA62_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA62_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CA62_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA62_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA62_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA62_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA62_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA62_E_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA62_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA62_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "A LITTLE"
                       3 "A LOT" ;
label define CA63      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA63_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CA63_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CA63_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CA63_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CA63_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA63_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA63_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CA63_E_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CA63_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA63_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "A LITTLE"
                       3 "A LOT" ;
label define CA64_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA64_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CA65      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA66      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA67      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA68      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA69      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA70      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA71      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA72      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CA73      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CB1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EXCELLENT" 2 "GOOD"
                       3 "FAIR" 4 "POOR" ;
label define CB2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MUCH BETTER" 2 "BETTER"
                       3 "THE SAME" 4 "WORSE" 5 "MUCH WORSE" ;
label define CB3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MUCH BETTER" 2 "BETTER"
                       3 "THE SAME" 4 "WORSE" 5 "MUCH WORSE" ;
label define CB4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB4A_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB6_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CB6_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CB6_B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CB6_B_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CB6_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "1-3 MOS" 6 "4-6 MOS"
                       9 "7-9 MOS" ;
label define CB6_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VERY MILD"
                       2 "MILD" 3 "MODERATE" 4 "SEVERE" ;
label define CB6_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB6F_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CB6F_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CB6F_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CB6F_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CB6F_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define CB6F_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CB6G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VERY MILD"
                       2 "MILD" 3 "MODERATE" 4 "SEVERATE" ;
label define CB8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB10_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB10_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB10_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB10_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_E   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB10_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB10A_F   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR"
                       2 "SOMEWHAT POOR" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CB12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POORLY"
                       2 "SOMEWHAT POORLY" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CB13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POORLY"
                       2 "SOMEWHAT POORLY" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CB14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POORLY"
                       2 "SOMEWHAT POORLY" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CB15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define CB15_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CB17_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CB18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO CARE RECEIVED"
                       1 "PRIV PHYSICIAN" 2 "HOSPITAL CLINIC"
                       3 "HOSPITAL EMERGENCY ROOM"
                       4 "HMO/OTHER GROUP HEALTH PLAN" 5 "URGENT CARE CLINIC"
                       6 "COMMUNITY HEALTH CTR" 7 "PUB CLINIC"
                       8 "DRUG/ALCOHOL TX PROG"
                       9 "CLINIC/NURSE AT SCHOOL/WORK" 10 "OTHER" ;
label define CB19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CB19A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB19A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CB19_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CB19_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED DISORDERS" 2 "MENTAL DISORDERS"
                       3 "ALL OTHER DISORDERS" ;
label define CB19_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CB22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB22A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CB22A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CB22A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CB22A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CB22B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define CB22B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define CB22B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define CB23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define CB24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define CB25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CB25A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "A LITTLE"
                       3 "A LOT" ;
label define C_C0      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CC4_A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CC4_A_S   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CC8_A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CC8_A_S   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CD1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL IMPORTANT"
                       1 "NOT TOO IMPORTANT" 2 "FAIRLY IMPORTANT"
                       3 "VERY IMPORTANT" ;
label define CD2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN ONCE/MONTH" 2 "ABOUT ONCE/MONTH"
                       3 "2 OR 3 TIMES A MONTH" 4 "ONCE/WK"
                       5 "MORE THAN ONCE/WK" ;
label define CD3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN ONCE/MONTH" 2 "ABOUT ONCE/MONTH"
                       3 "2 OR 3 TIMES A MONTH" 4 "ONCE/WK"
                       5 "MORE THAN ONCE/WK" ;
label define CD4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN ONCE/MONTH" 2 "ABOUT ONCE/MONTH"
                       3 "2 OR 3 TIMES A MONTH" 4 "ONCE/WK"
                       5 "MORE THAN ONCE/WK" ;
label define CD5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN ONCE/MONTH" 2 "ABOUT ONCE/MONTH"
                       3 "2 OR 3 TIMES/MONTH" 4 "ONCE/WK"
                       5 "MORE THAN ONCE/WK" ;
label define CD6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALMOST ALWAYS"
                       5 "IF VOL: NEVER HAVE PROBS" ;
label define CD7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STOP EXISTING"
                       2 "AFTERLIFE" 3 "IF VOL: DON'T KNOW" ;
label define CD7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY AGREE"
                       2 "AGREE SOMEWHAT" 3 "DISAGREE SOMEWHAT"
                       4 "STRONGLY DISAGREE" ;
label define CD7_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY AGREE"
                       2 "AGREE SOMEWHAT" 3 "DISAGREE SOMEWHAT"
                       4 "STRONGLY DISAGREE" ;
label define CD8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "SOMEWHAT IMPORTANT" 2 "VERY IMPORTANT" ;
label define CD9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CD18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "DISAGREE" 3 "AGREE" 4 "STRONGLY AGREE" ;
label define CE1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "RELEVANT EXAMPLE"
                       2 "NOT RELEVANT EXAMPLE" ;
label define CE1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHNG/NO DEFINITE DIAGNOSIS" ;
label define CE1_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE1_N     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_N     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_N     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_O     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE3_O     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_P     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE2_Q     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE5_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CE5_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CE5A_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CE5_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CE6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CE10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CE11_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONLY OWN SYMPTOMS/BEING OVERWEIGHT"
                       2 "ANYTHING ELSE" ;
label define CE12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_L    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_N    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_O    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_P    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_Q    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_R    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_S    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_T    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_U    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_V    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE12_W    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES"
                       2 "NO/VOL. DUE TO PHYS ILL/DRUG/ALC" ;
label define CE13_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CE13_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CE14_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CE14_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF2F_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF2_F_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF2G_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF2_G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF2_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF3_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF3_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF3_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF4_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF4_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF4_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF5_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF5_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF5_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF6_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF6_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF6_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF7_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF7_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF7_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF8_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF8_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF8_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF9_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF9_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF9_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF10_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF10_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF10_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF11_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF11_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF11_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF12_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF12_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF12_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF13_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF13_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF13_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF14_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF14_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF14_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "IF VOLUNTEERED NO INTEREST EVER" ;
label define CF15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF15_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF15_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF15_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF16_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF16_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF16_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF17_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF17_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF21_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF21_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF21_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF22_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF22_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF22_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYS. ILL/INJ"
                       2 "MED/DRUG/ALC" 3 "NERVES/ANXIETY/STRESS/DEPRESSION"
                       4 "NOTHING/NO DEFINITE DIAGNOSIS" ;
label define CF23_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO, NO EXAM, DK" ;
label define CF23_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF23_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF26      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF27A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF27_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF27B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF27_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF30_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER BEEN A PERIOD"
                       2 "HAS BEEN A PERIOD" ;
label define CF30_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF30C_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF30_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF30D_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF30_D_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF31      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF31_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "OKAY"
                       2 "GLOOMY, LOW, ETC." ;
label define CF31_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF31C_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF31_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF31D_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF31_D_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF32_WKS  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       4680 "WHOLE LIFE OR > 19 YRS" ;
label define CF33_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF33_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF33A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF33_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CF33_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF34      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define CF34_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "OKAY SOME MOS" 2 "NO" ;
label define CF35      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF36      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF36_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF36_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF36_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF36_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF37      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF37_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, NOT ALL DUE TO DEATH" 2 "NO, ALL DUE TO DEATH" ;
label define CF37_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES, ALL DUE TO DEATH"
                       2 "NO, NOT ALL DUE TO DEATH" ;
label define CF38      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF39      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CF40      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CF41_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_9    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_10   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_14   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_15   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_16   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_17   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_17A  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_17B  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_19   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_20   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_24   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_25   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_26   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CF41_27   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "YES, OCCURRED DURING THIS SPELL"
                       2 "NO, DID NOT OCCUR THEN" ;
label define CG1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IMPORTANT"
                       2 "GOTTEN ALONG AS WELL WITHOUT IT"
                       3 "NO SEXUAL EXPERIENCE" ;
label define CG2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 94 "1 OR DK, BUT < 15"
                       95 "DK, BUT 15 OR OLDER" ;
label define CG3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CG4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "NO RELATIONSHIP LASTED 1 YR/LONG" ;
label define CG6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG6B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CG6_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CG6C_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CG6_C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CG6_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD VAGINAL INTERCOURSE" 1 "NONE" 2 "1 WOMAN"
                       3 "2-4 WOMEN" 4 "5-9 WOMEN" 5 "10-20 WOMEN"
                       6 "21-99 WOMEN" 7 "100+ WOMEN" ;
label define CG7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define CG8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "1 WOMAN"
                       3 "2-4 WOMEN" 4 "5-9 WOMEN" 5 "10-20 WOMEN"
                       6 "21-99 WOMEN" 7 "100+ WOMEN" ;
label define CG8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define CG9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER HAD SEX WITH A MAN"
                       1 "NONE" 2 "1 MAN" 3 "2-4 MEN" 4 "5-9 MEN"
                       5 "10-20 MEN" 6 "21-99 MEN" 7 "100+ MEN" ;
label define CG11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define CG12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1 PERSON" 2 "2-4 PEOPLE"
                       3 "5+ PEOPLE" ;
label define CG16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD VAGINAL INTERCOURSE W/MAN" 1 "NONE"
                       2 "1 MAN" 3 "2-4 MEN" 4 "5-9 MEN" 5 "10-20 MEN"
                       6 "21-99 MEN" 7 "100+ MEN" ;
label define CG16_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define CG17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD ANAL INTERCOURSE W/A MAN" 1 "NONE"
                       2 "1 MAN" 3 "2-4 MEN" 4 "5-9 MEN" 5 "10-20 MEN"
                       6 "21-99 MEN" 7 "100+ MEN" ;
label define CG17_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define CG18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CG22_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1 MAN" 2 "2-4 MEN"
                       3 "5+ MEN" ;
label define CH1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "1 OR DON'T KNOW, BUT UNDER 15"
                       95 "DON'T KNOW, BUT 15 OR OLDER" ;
label define CH8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "1 OR DON'T KNOW, BUT UNDER 15"
                       95 "DON'T KNOW, BUT 15 OR OLDER" ;
label define CH9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH10_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH13_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define CH14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH14_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define CH15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "FELT BAD ABOUT SOME, NOT OTHERS" ;
label define CH18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH18_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES, MORE THAN TWICE"
                       2 "NO" ;
label define CH19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH19_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define CH19_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "FELT BAD ABOUT SOME, NOT OTHERS" ;
label define CH20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH20_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH26_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH26_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CH26A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CH26_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define CH26_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CH30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES, NO OPPORTUNITY"
                       2 "NO, HAD OPPORTUNITY" ;
label define CJ1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ1_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME" 2 "MOST" ;
label define CJ3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ3_N     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME" 2 "MOST" ;
label define CJ5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ5_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ5_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ5_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ5_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ5_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "MODERATELY" 3 "QUITE A BIT"
                       4 "EXTREMELY" ;
label define CJ6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME" 2 "MOST" ;
label define CJ7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CJ7_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TRUE" 2 "FALSE" ;
label define CK1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CK20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "AGREE SOMEWHAT" 3 "VERY MUCH AGREE" ;
label define CL1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR"
                       2 "SOMEWHAT POOR" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CL2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR"
                       2 "SOMEWHAT POOR" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "AVERAGE OR GOOD" ;
label define CL3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL7_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CL7_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CL7_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CL7_6_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY SEVERE"
                       2 "MODERATELY SEVERE" 3 "NOT SEVERE" ;
label define CL7_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define CL7_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define CL7_8_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY SEVERE"
                       2 "MODERATELY SEVERE" 3 "NOT SEVERE" ;
label define CL8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CL10_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CL10_1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define CL10_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CL10_2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define CL10_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CL10_3_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define CL10_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CL10_4_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define CL11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL11_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define CL11_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define CL11_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define CL11_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define CL11_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define CL11_A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define CL12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EAGER" 2 "RECEPTIVE"
                       3 "NO REACTION" 4 "RELUCTANT" 5 "REFUSED"
                       6 "NOT DISCUSSED" ;
label define CL13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CL13_A_H  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CL13_A_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define CL14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ESSENTIALLY NORMAL"
                       2 "A LITTLE ABNORMAL" 3 "VERY ABNORMAL" ;
label define CM1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define CM2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM10_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM11_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM11_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define CM12_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define CM12_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define CM12_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define CM12_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define CM13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO ERRORS" 1 "1 ERROR"
                       2 "2 ERRORS" 3 "3 ERRORS" 4 "4 ERRORS" 5 "5 ERRORS" ;
label define CM14_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM14_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM14_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define CM15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM15_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP"
                       7 "CANT READ ENGLISH" ;
label define CM18_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM18_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM18_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define CM19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP"
                       7 "CANT WRITE (ENGLISH)" ;
label define CM20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP" ;
label define CM21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define FTWORK    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-13 WKS"
                       2 "14-39 WKS" 3 "40-52 WKS" ;
label define MSTAT     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MARRIED" 2 "SEPARATED"
                       3 "DIVORCED" 4 "WIDOWED" 5 "LIVING AS MARRIED"
                       6 "NEVER MARRIED" ;
label define SEX       1 "MALE" 2 "FEMALE" ;
label define AGE       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AGEGRP    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "18-20" 2 "21-25"
                       3 "26-30" 4 "31-35" 5 "36-44" 6 "OVER 44" ;
label define RACE      1 "CAUCASIAN/WHITE" 2 "AFRO-AMERICAN/BLACK"
                       3 "HISPANIC" 4 "OTHER" ;
label define EDLEV     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE"
                       1 "GRADE SCHOOL OR LESS" 2 "HIGH SCHOOL"
                       3 "HIGH SCHOOL DEGREE" 4 "SOME COLLEGE"
                       5 "JR COLLEGE/ASSOCIATE DEGREE" 6 "COLLEGE DEGREE"
                       7 "ADVANCED DEGREE" ;
label define RACESEX   1 "CAUCASIAN/WHITE MALE" 2 "AFRO-AMERICAN/BLACK MALE"
                       3 "HISPANIC MALE" 4 "OTHER MALE"
                       5 "CAUCASIAN/WHITE FEMALE"
                       6 "AFRO-AMERICAN/BLACK FEMALE" 7 "HISPANIC FEMALE"
                       8 "OTHER FEMALE" ;
label define CJ_STAT   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO LEGAL STATUS"
                       1 "IN JAIL/DETENTION" 2 "PROBATION" 3 "PAROLE"
                       4 "CASE PENDING" ;
label define HLTHINS   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "PRIVATE/OTHER"
                       2 "PUBLIC" ;
label define MAJSRC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO INCOME" 1 "LEGAL WORK"
                       2 "PUB ASSISTANCE" 3 "SOCIAL SECURITY"
                       4 "FAMILY/FRIENDS" 5 "ILLEGAL SOURCES"
                       6 "OTHER SOURCES" ;
label define REFER     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "SELF(ONLY IF NO PRIM/SECONDARY MENTION)"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM" 30 "PROBATION/PAROLE"
                       40 "PRISON SYSTEM" 50 "FAMILY/FRIENDS" 60 "SCHOOL"
                       70 "EMPLOYER" 80 "VETERAN" 90 "OTHER" ;
label define RESTRICT  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO WKS RESTRICTED"
                       1 "1-4 WKS RESTRICTED" 2 "5-13 WKS RESTRICTED"
                       3 "14-26 WKS RESTRICTED" 4 "27-39 WKS RESTRICTED"
                       5 "40-50 WKS RESTRICTED" 6 "51-52 WKS RESTRICTED" ;
label define PDRUG     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define PDRUGFRQ  -9 "NO PRIMARY DRUG DENOTED" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO USE" 1 "< ONCE/WK"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4 TO MORE TIMES/DAY" ;
label define FAVDRUG   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define HVY_ALC   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT A HEAVY USER"
                       1 "HEAVY ALCOHOL USER" ;
label define DRUGPAT   1 "HEROIN/NARCOTIC/NO COKE"
                       2 "COKE W/HEROIN OR NARCOTICS" 3 "COKE ONLY"
                       4 "COKE AND ALCOHOL" 5 "COKE PLUS OTHER DRUGS"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL" ;
label define TOPS_PAT  1 "HEROIN" 2 "HEROIN AND OPIOIDS" 3 "OTHER OPIOIDS"
                       4 "MULTIPLE NON-OPIOIDS" 5 "SINGLE NON-OPIOIDS"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL/MINIMAL USE" ;
label define ALCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define MRJWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define COCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define CRKWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HERWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define NARWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define SEDWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define AMPWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HALWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define INHWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HERHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "USED 1-5 TIMES ONLY"
                       2 "USED SPORATICALLY OR MONTHLY"
                       3 "USED MORE THAN 4 WKS ON WEEKLY BASIS"
                       4 "USED MORE THAN 4 WKS ON DAILY BASIS" ;
label define COCHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "USED 1-5 TIMES ONLY"
                       2 "USED SPORATICALLY OR MONTHLY"
                       3 "USED MORE THAN 4 WKS ON WEEKLY BASIS"
                       4 "USED MORE THAN 4 WKS ON DAILY BASIS" ;
label define DRUGTX    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define DRGTXAGE  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define MRTX1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define MRTX2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define MRTX3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define MRTX4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CDC_M = . if (CDC_M <= -1 )
replace CDC_Y = . if (CDC_Y <= -1 )
replace CT_L_I = . if (CT_L_I <= -1 )
replace CA4 = . if (CA4 <= -1 )
replace CA4_A = . if (CA4_A <= -1 )
replace CA5 = . if (CA5 <= -1 )
replace CA5_A = . if (CA5_A <= -1 )
replace CA6_WKS = . if (CA6_WKS <= -1 )
replace CA6_A = . if (CA6_A <= -1 )
replace CA7 = . if (CA7 <= -1 )
replace CA7_A = . if (CA7_A <= -1 )
replace CA7_B = . if (CA7_B <= -1 )
replace CA7_C = . if (CA7_C <= -1 )
replace CA7_D = . if (CA7_D <= -1 )
replace CA8 = . if (CA8 <= -1 )
replace CA9 = . if (CA9 <= -1 )
replace CA10 = . if (CA10 <= -1 )
replace CA10_WKS = . if (CA10_WKS <= -1 )
replace CA10_A = . if (CA10_A <= -1 )
replace CA10_B = . if (CA10_B <= -1 )
replace CA10_C = . if (CA10_C <= -1 )
replace CA10_D = . if (CA10_D <= -1 )
replace CA11 = . if (CA11 <= -1 )
replace CA11_A = . if (CA11_A <= -1 )
replace CA11_B = . if (CA11_B <= -1 )
replace CA11_C = . if (CA11_C <= -1 )
replace CA11_D = . if (CA11_D <= -1 )
replace CA11_E = . if (CA11_E <= -1 )
replace CA12 = . if (CA12 <= -1 )
replace CA13 = . if (CA13 <= -1 )
replace CA13_M = . if (CA13_M <= -1 )
replace CA13_A = . if (CA13_A <= -1 )
replace CA13_B_1 = . if (CA13_B_1 <= -1 )
replace CA14_WKS = . if (CA14_WKS <= -1 )
replace CA15 = . if (CA15 <= -1 )
replace CA15_M = . if (CA15_M <= -1 )
replace CA15_A = . if (CA15_A <= -1 )
replace CA15_B_1 = . if (CA15_B_1 <= -1 )
replace CA16 = . if (CA16 <= -1 )
replace CA16_WKS = . if (CA16_WKS <= -1 )
replace CA16_M = . if (CA16_M <= -1 )
replace CA16_A_1 = . if (CA16_A_1 <= -1 )
replace CA16_B = . if (CA16_B <= -1 )
replace CA17 = . if (CA17 <= -1 )
replace CA17_M = . if (CA17_M <= -1 )
replace CA17_A = . if (CA17_A <= -1 )
replace CA17_B_1 = . if (CA17_B_1 <= -1 )
replace CA18 = . if (CA18 <= -1 )
replace CA19 = . if (CA19 <= -1 )
replace CA19_A = . if (CA19_A <= -1 )
replace CA20 = . if (CA20 <= -1 )
replace CA20_A = . if (CA20_A <= -1 )
replace CA20_B = . if (CA20_B <= -1 )
replace CA20_C = . if (CA20_C <= -1 )
replace CA20_D = . if (CA20_D <= -1 )
replace CA21 = . if (CA21 <= -1 )
replace CA21_A = . if (CA21_A <= -1 )
replace CA21B_01 = . if (CA21B_01 <= -1 )
replace CA21B_02 = . if (CA21B_02 <= -1 )
replace CA21B_03 = . if (CA21B_03 <= -1 )
replace CA21B_04 = . if (CA21B_04 <= -1 )
replace CA22 = . if (CA22 <= -1 )
replace CA23_1 = . if (CA23_1 <= -1 )
replace CA23_2 = . if (CA23_2 <= -1 )
replace CA23_3 = . if (CA23_3 <= -1 )
replace CA23_4 = . if (CA23_4 <= -1 )
replace CA23_5 = . if (CA23_5 <= -1 )
replace CA23_6 = . if (CA23_6 <= -1 )
replace CA24 = . if (CA24 <= -1 )
replace CA25_A = . if (CA25_A <= -1 )
replace CA25_B = . if (CA25_B <= -1 )
replace CA25_C = . if (CA25_C <= -1 )
replace CA25_D = . if (CA25_D <= -1 )
replace CA25_E = . if (CA25_E <= -1 )
replace CA26 = . if (CA26 <= -1 )
replace CA27 = . if (CA27 <= -1 )
replace CA27_A = . if (CA27_A <= -1 )
replace CA28 = . if (CA28 <= -1 )
replace CA28_A = . if (CA28_A <= -1 )
replace CA29 = . if (CA29 <= -1 )
replace CA30 = . if (CA30 <= -1 )
replace CA30_A = . if (CA30_A <= -1 )
replace CA31 = . if (CA31 <= -1 )
replace CA32 = . if (CA32 <= -1 )
replace CA32A_01 = . if (CA32A_01 <= -1 )
replace CA32A_02 = . if (CA32A_02 <= -1 )
replace CA32A_03 = . if (CA32A_03 <= -1 )
replace CA32A_04 = . if (CA32A_04 <= -1 )
replace CA32A_05 = . if (CA32A_05 <= -1 )
replace CA32A_06 = . if (CA32A_06 <= -1 )
replace CA33 = . if (CA33 <= -1 )
replace CA33A_02 = . if (CA33A_02 <= -1 )
replace CA33A_03 = . if (CA33A_03 <= -1 )
replace CA33A_04 = . if (CA33A_04 <= -1 )
replace CA33A_05 = . if (CA33A_05 <= -1 )
replace CA33A_06 = . if (CA33A_06 <= -1 )
replace CA34_0 = . if (CA34_0 <= -1 )
replace CA34_1 = . if (CA34_1 <= -1 )
replace CA34_2 = . if (CA34_2 <= -1 )
replace CA34_3 = . if (CA34_3 <= -1 )
replace CA35 = . if (CA35 <= -1 )
replace CA36 = . if (CA36 <= -1 )
replace CA36_A = . if (CA36_A <= -1 )
replace CA37_A = . if (CA37_A <= -1 )
replace CA37_B = . if (CA37_B <= -1 )
replace CA37_C = . if (CA37_C <= -1 )
replace CA37_D = . if (CA37_D <= -1 )
replace CA38 = . if (CA38 <= -1 )
replace CA39 = . if (CA39 <= -1 )
replace CA40 = . if (CA40 <= -1 )
replace CA41 = . if (CA41 <= -1 )
replace CA42 = . if (CA42 <= -1 )
replace CA43 = . if (CA43 <= -1 )
replace CA44 = . if (CA44 <= -1 )
replace CA45_M = . if (CA45_M <= -1 )
replace CA45_1 = . if (CA45_1 <= -1 )
replace CA45A_M = . if (CA45A_M <= -1 )
replace CA45_A_1 = . if (CA45_A_1 <= -1 )
replace CA45_B = . if (CA45_B <= -1 )
replace CA46 = . if (CA46 <= -1 )
replace CA46_A = . if (CA46_A <= -1 )
replace CA46_B = . if (CA46_B <= -1 )
replace CA46_C = . if (CA46_C <= -1 )
replace CA46_D = . if (CA46_D <= -1 )
replace CA46_E = . if (CA46_E <= -1 )
replace CA47 = . if (CA47 <= -1 )
replace CA47_A = . if (CA47_A <= -1 )
replace CA48 = . if (CA48 <= -1 )
replace CA49 = . if (CA49 <= -1 )
replace CA50 = . if (CA50 <= -1 )
replace CA51 = . if (CA51 <= -1 )
replace CA52 = . if (CA52 <= -1 )
replace CA53 = . if (CA53 <= -1 )
replace CA54 = . if (CA54 <= -1 )
replace CA55 = . if (CA55 <= -1 )
replace CA56_A = . if (CA56_A <= -1 )
replace CA56_B = . if (CA56_B <= -1 )
replace CA56_C = . if (CA56_C <= -1 )
replace CA57_A = . if (CA57_A <= -1 )
replace CA57_B = . if (CA57_B <= -1 )
replace CA57_C = . if (CA57_C <= -1 )
replace CA57_D = . if (CA57_D <= -1 )
replace CA57_E = . if (CA57_E <= -1 )
replace CA57_F = . if (CA57_F <= -1 )
replace CA58 = . if (CA58 <= -1 )
replace CA59 = . if (CA59 <= -1 )
replace CA60 = . if (CA60 <= -1 )
replace CA61 = . if (CA61 <= -1 )
replace CA61_A = . if (CA61_A <= -1 )
replace CA61_B = . if (CA61_B <= -1 )
replace CA61_C = . if (CA61_C <= -1 )
replace CA62 = . if (CA62 <= -1 )
replace CA62_M = . if (CA62_M <= -1 )
replace CA62_A_1 = . if (CA62_A_1 <= -1 )
replace CA62_A_2 = . if (CA62_A_2 <= -1 )
replace CA62_A_3 = . if (CA62_A_3 <= -1 )
replace CA62_B = . if (CA62_B <= -1 )
replace CA62_C = . if (CA62_C <= -1 )
replace CA62_D = . if (CA62_D <= -1 )
replace CA62_E_1 = . if (CA62_E_1 <= -1 )
replace CA62_F = . if (CA62_F <= -1 )
replace CA62_G = . if (CA62_G <= -1 )
replace CA63 = . if (CA63 <= -1 )
replace CA63_M = . if (CA63_M <= -1 )
replace CA63_A_1 = . if (CA63_A_1 <= -1 )
replace CA63_A_2 = . if (CA63_A_2 <= -1 )
replace CA63_A_3 = . if (CA63_A_3 <= -1 )
replace CA63_B = . if (CA63_B <= -1 )
replace CA63_C = . if (CA63_C <= -1 )
replace CA63_D = . if (CA63_D <= -1 )
replace CA63_E_1 = . if (CA63_E_1 <= -1 )
replace CA63_F = . if (CA63_F <= -1 )
replace CA63_G = . if (CA63_G <= -1 )
replace CA64_A = . if (CA64_A <= -1 )
replace CA64_B = . if (CA64_B <= -1 )
replace CA65 = . if (CA65 <= -1 )
replace CA66 = . if (CA66 <= -1 )
replace CA67 = . if (CA67 <= -1 )
replace CA68 = . if (CA68 <= -1 )
replace CA69 = . if (CA69 <= -1 )
replace CA70 = . if (CA70 <= -1 )
replace CA71 = . if (CA71 <= -1 )
replace CA72 = . if (CA72 <= -1 )
replace CA73 = . if (CA73 <= -1 )
replace CB1 = . if (CB1 <= -1 )
replace CB2 = . if (CB2 <= -1 )
replace CB3 = . if (CB3 <= -1 )
replace CB4_A = . if (CB4_A <= -1 )
replace CB4A_A = . if (CB4A_A <= -1 )
replace CB4_B = . if (CB4_B <= -1 )
replace CB4A_B = . if (CB4A_B <= -1 )
replace CB4_C = . if (CB4_C <= -1 )
replace CB4A_C = . if (CB4A_C <= -1 )
replace CB4_D = . if (CB4_D <= -1 )
replace CB4A_D = . if (CB4A_D <= -1 )
replace CB4_E = . if (CB4_E <= -1 )
replace CB4A_E = . if (CB4A_E <= -1 )
replace CB4_F = . if (CB4_F <= -1 )
replace CB4A_F = . if (CB4A_F <= -1 )
replace CB4_G = . if (CB4_G <= -1 )
replace CB4A_G = . if (CB4A_G <= -1 )
replace CB4_H = . if (CB4_H <= -1 )
replace CB4A_H = . if (CB4A_H <= -1 )
replace CB4_I = . if (CB4_I <= -1 )
replace CB4A_I = . if (CB4A_I <= -1 )
replace CB4_J = . if (CB4_J <= -1 )
replace CB4A_J = . if (CB4A_J <= -1 )
replace CB4_K = . if (CB4_K <= -1 )
replace CB4A_K = . if (CB4A_K <= -1 )
replace CB5 = . if (CB5 <= -1 )
replace CB6 = . if (CB6 <= -1 )
replace CB6A = . if (CB6A <= -1 )
replace CB6_B_1 = . if (CB6_B_1 <= -1 )
replace CB6_B_2 = . if (CB6_B_2 <= -1 )
replace CB6_B_3 = . if (CB6_B_3 <= -1 )
replace CB6_B_4 = . if (CB6_B_4 <= -1 )
replace CB6_C = . if (CB6_C <= -1 )
replace CB6_D = . if (CB6_D <= -1 )
replace CB6_E = . if (CB6_E <= -1 )
replace CB6F_1 = . if (CB6F_1 <= -1 )
replace CB6F_2 = . if (CB6F_2 <= -1 )
replace CB6F_3 = . if (CB6F_3 <= -1 )
replace CB6F_4 = . if (CB6F_4 <= -1 )
replace CB6F_5 = . if (CB6F_5 <= -1 )
replace CB6F_6 = . if (CB6F_6 <= -1 )
replace CB6G = . if (CB6G <= -1 )
replace CB7 = . if (CB7 <= -1 )
replace CB8 = . if (CB8 <= -1 )
replace CB9 = . if (CB9 <= -1 )
replace CB10_A = . if (CB10_A <= -1 )
replace CB10A_A = . if (CB10A_A <= -1 )
replace CB10_B = . if (CB10_B <= -1 )
replace CB10A_B = . if (CB10A_B <= -1 )
replace CB10_C = . if (CB10_C <= -1 )
replace CB10A_C = . if (CB10A_C <= -1 )
replace CB10_D = . if (CB10_D <= -1 )
replace CB10A_D = . if (CB10A_D <= -1 )
replace CB10_E = . if (CB10_E <= -1 )
replace CB10A_E = . if (CB10A_E <= -1 )
replace CB10_F = . if (CB10_F <= -1 )
replace CB10A_F = . if (CB10A_F <= -1 )
replace CB11 = . if (CB11 <= -1 )
replace CB12 = . if (CB12 <= -1 )
replace CB13 = . if (CB13 <= -1 )
replace CB14 = . if (CB14 <= -1 )
replace CB15 = . if (CB15 <= -1 )
replace CB15_A = . if (CB15_A <= -1 )
replace CB15_B = . if (CB15_B <= -1 )
replace CB16 = . if (CB16 <= -1 )
replace CB17 = . if (CB17 <= -1 )
replace CB17_A = . if (CB17_A <= -1 )
replace CB18 = . if (CB18 <= -1 )
replace CB19 = . if (CB19 <= -1 )
replace CB19A_M = . if (CB19A_M <= -1 )
replace CB19A_1 = . if (CB19A_1 <= -1 )
replace CB19_B = . if (CB19_B <= -1 )
replace CB19_C = . if (CB19_C <= -1 )
replace CB19_D = . if (CB19_D <= -1 )
replace CB20 = . if (CB20 <= -1 )
replace CB21 = . if (CB21 <= -1 )
replace CB22 = . if (CB22 <= -1 )
replace CB22A_1 = . if (CB22A_1 <= -1 )
replace CB22A_2 = . if (CB22A_2 <= -1 )
replace CB22A_3 = . if (CB22A_3 <= -1 )
replace CB22A_4 = . if (CB22A_4 <= -1 )
replace CB22B_1 = . if (CB22B_1 <= -1 )
replace CB22B_2 = . if (CB22B_2 <= -1 )
replace CB22B_3 = . if (CB22B_3 <= -1 )
replace CB23 = . if (CB23 <= -1 )
replace CB24 = . if (CB24 <= -1 )
replace CB25 = . if (CB25 <= -1 )
replace CB25A = . if (CB25A <= -1 )
replace C_C0 = . if (C_C0 <= -1 )
replace CC4_A_M = . if (CC4_A_M <= -1 )
replace CC4_A_S = . if (CC4_A_S <= -1 )
replace CC8_A_M = . if (CC8_A_M <= -1 )
replace CC8_A_S = . if (CC8_A_S <= -1 )
replace CD1 = . if (CD1 <= -1 )
replace CD2 = . if (CD2 <= -1 )
replace CD3 = . if (CD3 <= -1 )
replace CD4 = . if (CD4 <= -1 )
replace CD5 = . if (CD5 <= -1 )
replace CD6 = . if (CD6 <= -1 )
replace CD7 = . if (CD7 <= -1 )
replace CD7_A = . if (CD7_A <= -1 )
replace CD7_B = . if (CD7_B <= -1 )
replace CD8 = . if (CD8 <= -1 )
replace CD9 = . if (CD9 <= -1 )
replace CD10 = . if (CD10 <= -1 )
replace CD11 = . if (CD11 <= -1 )
replace CD12 = . if (CD12 <= -1 )
replace CD13 = . if (CD13 <= -1 )
replace CD14 = . if (CD14 <= -1 )
replace CD15 = . if (CD15 <= -1 )
replace CD16 = . if (CD16 <= -1 )
replace CD17 = . if (CD17 <= -1 )
replace CD18 = . if (CD18 <= -1 )
replace CE1 = . if (CE1 <= -1 )
replace CE1_A = . if (CE1_A <= -1 )
replace CE1_B = . if (CE1_B <= -1 )
replace CE1_C = . if (CE1_C <= -1 )
replace CE1_D = . if (CE1_D <= -1 )
replace CE1_E = . if (CE1_E <= -1 )
replace CE1_F = . if (CE1_F <= -1 )
replace CE1_G = . if (CE1_G <= -1 )
replace CE1_H = . if (CE1_H <= -1 )
replace CE1_I = . if (CE1_I <= -1 )
replace CE1_J = . if (CE1_J <= -1 )
replace CE1_K = . if (CE1_K <= -1 )
replace CE1_L = . if (CE1_L <= -1 )
replace CE1_M = . if (CE1_M <= -1 )
replace CE1_N = . if (CE1_N <= -1 )
replace CE2_A = . if (CE2_A <= -1 )
replace CE3_A = . if (CE3_A <= -1 )
replace CE2_B = . if (CE2_B <= -1 )
replace CE3_B = . if (CE3_B <= -1 )
replace CE2_C = . if (CE2_C <= -1 )
replace CE3_C = . if (CE3_C <= -1 )
replace CE2_D = . if (CE2_D <= -1 )
replace CE3_D = . if (CE3_D <= -1 )
replace CE2_E = . if (CE2_E <= -1 )
replace CE2_F = . if (CE2_F <= -1 )
replace CE2_G = . if (CE2_G <= -1 )
replace CE2_H = . if (CE2_H <= -1 )
replace CE2_I = . if (CE2_I <= -1 )
replace CE2_J = . if (CE2_J <= -1 )
replace CE2_K = . if (CE2_K <= -1 )
replace CE2_L = . if (CE2_L <= -1 )
replace CE2_M = . if (CE2_M <= -1 )
replace CE2_N = . if (CE2_N <= -1 )
replace CE3_N = . if (CE3_N <= -1 )
replace CE2_O = . if (CE2_O <= -1 )
replace CE3_O = . if (CE3_O <= -1 )
replace CE2_P = . if (CE2_P <= -1 )
replace CE2_Q = . if (CE2_Q <= -1 )
replace CE4 = . if (CE4 <= -1 )
replace CE5_1 = . if (CE5_1 <= -1 )
replace CE5_M = . if (CE5_M <= -1 )
replace CE5A_M = . if (CE5A_M <= -1 )
replace CE5_A_1 = . if (CE5_A_1 <= -1 )
replace CE6 = . if (CE6 <= -1 )
replace CE7 = . if (CE7 <= -1 )
replace CE7_A = . if (CE7_A <= -1 )
replace CE8 = . if (CE8 <= -1 )
replace CE9 = . if (CE9 <= -1 )
replace CE9_A = . if (CE9_A <= -1 )
replace CE10 = . if (CE10 <= -1 )
replace CE10_A = . if (CE10_A <= -1 )
replace CE11 = . if (CE11 <= -1 )
replace CE11_A = . if (CE11_A <= -1 )
replace CE11_B = . if (CE11_B <= -1 )
replace CE12_A = . if (CE12_A <= -1 )
replace CE12_B = . if (CE12_B <= -1 )
replace CE12_C = . if (CE12_C <= -1 )
replace CE12_D = . if (CE12_D <= -1 )
replace CE12_E = . if (CE12_E <= -1 )
replace CE12_F = . if (CE12_F <= -1 )
replace CE12_G = . if (CE12_G <= -1 )
replace CE12_H = . if (CE12_H <= -1 )
replace CE12_I = . if (CE12_I <= -1 )
replace CE12_J = . if (CE12_J <= -1 )
replace CE12_K = . if (CE12_K <= -1 )
replace CE12_L = . if (CE12_L <= -1 )
replace CE12_M = . if (CE12_M <= -1 )
replace CE12_N = . if (CE12_N <= -1 )
replace CE12_O = . if (CE12_O <= -1 )
replace CE12_P = . if (CE12_P <= -1 )
replace CE12_Q = . if (CE12_Q <= -1 )
replace CE12_R = . if (CE12_R <= -1 )
replace CE12_S = . if (CE12_S <= -1 )
replace CE12_T = . if (CE12_T <= -1 )
replace CE12_U = . if (CE12_U <= -1 )
replace CE12_V = . if (CE12_V <= -1 )
replace CE12_W = . if (CE12_W <= -1 )
replace CE13_M = . if (CE13_M <= -1 )
replace CE13_1 = . if (CE13_1 <= -1 )
replace CE14_M = . if (CE14_M <= -1 )
replace CE14_1 = . if (CE14_1 <= -1 )
replace CF1 = . if (CF1 <= -1 )
replace CF2 = . if (CF2 <= -1 )
replace CF2_A = . if (CF2_A <= -1 )
replace CF2_B = . if (CF2_B <= -1 )
replace CF2_C = . if (CF2_C <= -1 )
replace CF2_D = . if (CF2_D <= -1 )
replace CF2_E = . if (CF2_E <= -1 )
replace CF2F_M = . if (CF2F_M <= -1 )
replace CF2_F_1 = . if (CF2_F_1 <= -1 )
replace CF2G_M = . if (CF2G_M <= -1 )
replace CF2_G_1 = . if (CF2_G_1 <= -1 )
replace CF2_H = . if (CF2_H <= -1 )
replace CF3 = . if (CF3 <= -1 )
replace CF3_A = . if (CF3_A <= -1 )
replace CF3_B = . if (CF3_B <= -1 )
replace CF3_C = . if (CF3_C <= -1 )
replace CF3_D = . if (CF3_D <= -1 )
replace CF3_E = . if (CF3_E <= -1 )
replace CF3_F = . if (CF3_F <= -1 )
replace CF3_G = . if (CF3_G <= -1 )
replace CF3_H = . if (CF3_H <= -1 )
replace CF3_I = . if (CF3_I <= -1 )
replace CF4 = . if (CF4 <= -1 )
replace CF4_A = . if (CF4_A <= -1 )
replace CF4_B = . if (CF4_B <= -1 )
replace CF4_C = . if (CF4_C <= -1 )
replace CF4_D = . if (CF4_D <= -1 )
replace CF4_E = . if (CF4_E <= -1 )
replace CF4_F = . if (CF4_F <= -1 )
replace CF4_G = . if (CF4_G <= -1 )
replace CF4_H = . if (CF4_H <= -1 )
replace CF4_I = . if (CF4_I <= -1 )
replace CF5 = . if (CF5 <= -1 )
replace CF5_A = . if (CF5_A <= -1 )
replace CF5_B = . if (CF5_B <= -1 )
replace CF5_C = . if (CF5_C <= -1 )
replace CF5_D = . if (CF5_D <= -1 )
replace CF5_E = . if (CF5_E <= -1 )
replace CF5_F = . if (CF5_F <= -1 )
replace CF5_G = . if (CF5_G <= -1 )
replace CF5_H = . if (CF5_H <= -1 )
replace CF5_I = . if (CF5_I <= -1 )
replace CF6 = . if (CF6 <= -1 )
replace CF6_A = . if (CF6_A <= -1 )
replace CF6_B = . if (CF6_B <= -1 )
replace CF6_C = . if (CF6_C <= -1 )
replace CF6_D = . if (CF6_D <= -1 )
replace CF6_E = . if (CF6_E <= -1 )
replace CF6_F = . if (CF6_F <= -1 )
replace CF6_G = . if (CF6_G <= -1 )
replace CF6_H = . if (CF6_H <= -1 )
replace CF6_I = . if (CF6_I <= -1 )
replace CF7 = . if (CF7 <= -1 )
replace CF7_A = . if (CF7_A <= -1 )
replace CF7_B = . if (CF7_B <= -1 )
replace CF7_C = . if (CF7_C <= -1 )
replace CF7_D = . if (CF7_D <= -1 )
replace CF7_E = . if (CF7_E <= -1 )
replace CF7_F = . if (CF7_F <= -1 )
replace CF7_G = . if (CF7_G <= -1 )
replace CF7_H = . if (CF7_H <= -1 )
replace CF7_I = . if (CF7_I <= -1 )
replace CF8 = . if (CF8 <= -1 )
replace CF8_A = . if (CF8_A <= -1 )
replace CF8_B = . if (CF8_B <= -1 )
replace CF8_C = . if (CF8_C <= -1 )
replace CF8_D = . if (CF8_D <= -1 )
replace CF8_E = . if (CF8_E <= -1 )
replace CF8_F = . if (CF8_F <= -1 )
replace CF8_G = . if (CF8_G <= -1 )
replace CF8_H = . if (CF8_H <= -1 )
replace CF8_I = . if (CF8_I <= -1 )
replace CF9 = . if (CF9 <= -1 )
replace CF9_A = . if (CF9_A <= -1 )
replace CF9_B = . if (CF9_B <= -1 )
replace CF9_C = . if (CF9_C <= -1 )
replace CF9_D = . if (CF9_D <= -1 )
replace CF9_E = . if (CF9_E <= -1 )
replace CF9_F = . if (CF9_F <= -1 )
replace CF9_G = . if (CF9_G <= -1 )
replace CF9_H = . if (CF9_H <= -1 )
replace CF9_I = . if (CF9_I <= -1 )
replace CF10 = . if (CF10 <= -1 )
replace CF10_A = . if (CF10_A <= -1 )
replace CF10_B = . if (CF10_B <= -1 )
replace CF10_C = . if (CF10_C <= -1 )
replace CF10_D = . if (CF10_D <= -1 )
replace CF10_E = . if (CF10_E <= -1 )
replace CF10_F = . if (CF10_F <= -1 )
replace CF10_G = . if (CF10_G <= -1 )
replace CF10_H = . if (CF10_H <= -1 )
replace CF10_I = . if (CF10_I <= -1 )
replace CF11 = . if (CF11 <= -1 )
replace CF11_A = . if (CF11_A <= -1 )
replace CF11_B = . if (CF11_B <= -1 )
replace CF11_C = . if (CF11_C <= -1 )
replace CF11_D = . if (CF11_D <= -1 )
replace CF11_E = . if (CF11_E <= -1 )
replace CF11_F = . if (CF11_F <= -1 )
replace CF11_G = . if (CF11_G <= -1 )
replace CF11_H = . if (CF11_H <= -1 )
replace CF11_I = . if (CF11_I <= -1 )
replace CF12 = . if (CF12 <= -1 )
replace CF12_A = . if (CF12_A <= -1 )
replace CF12_B = . if (CF12_B <= -1 )
replace CF12_C = . if (CF12_C <= -1 )
replace CF12_D = . if (CF12_D <= -1 )
replace CF12_E = . if (CF12_E <= -1 )
replace CF12_F = . if (CF12_F <= -1 )
replace CF12_G = . if (CF12_G <= -1 )
replace CF12_H = . if (CF12_H <= -1 )
replace CF12_I = . if (CF12_I <= -1 )
replace CF13 = . if (CF13 <= -1 )
replace CF13_A = . if (CF13_A <= -1 )
replace CF13_B = . if (CF13_B <= -1 )
replace CF13_C = . if (CF13_C <= -1 )
replace CF13_D = . if (CF13_D <= -1 )
replace CF13_E = . if (CF13_E <= -1 )
replace CF13_F = . if (CF13_F <= -1 )
replace CF13_G = . if (CF13_G <= -1 )
replace CF13_H = . if (CF13_H <= -1 )
replace CF13_I = . if (CF13_I <= -1 )
replace CF14 = . if (CF14 <= -1 )
replace CF14_A = . if (CF14_A <= -1 )
replace CF14_B = . if (CF14_B <= -1 )
replace CF14_C = . if (CF14_C <= -1 )
replace CF14_D = . if (CF14_D <= -1 )
replace CF14_E = . if (CF14_E <= -1 )
replace CF14_F = . if (CF14_F <= -1 )
replace CF14_G = . if (CF14_G <= -1 )
replace CF14_H = . if (CF14_H <= -1 )
replace CF14_I = . if (CF14_I <= -1 )
replace CF15 = . if (CF15 <= -1 )
replace CF15_A = . if (CF15_A <= -1 )
replace CF15_B = . if (CF15_B <= -1 )
replace CF15_C = . if (CF15_C <= -1 )
replace CF15_D = . if (CF15_D <= -1 )
replace CF15_E = . if (CF15_E <= -1 )
replace CF15_F = . if (CF15_F <= -1 )
replace CF15_G = . if (CF15_G <= -1 )
replace CF15_H = . if (CF15_H <= -1 )
replace CF15_I = . if (CF15_I <= -1 )
replace CF16 = . if (CF16 <= -1 )
replace CF16_A = . if (CF16_A <= -1 )
replace CF16_B = . if (CF16_B <= -1 )
replace CF16_C = . if (CF16_C <= -1 )
replace CF16_D = . if (CF16_D <= -1 )
replace CF16_E = . if (CF16_E <= -1 )
replace CF16_F = . if (CF16_F <= -1 )
replace CF16_G = . if (CF16_G <= -1 )
replace CF16_H = . if (CF16_H <= -1 )
replace CF16_I = . if (CF16_I <= -1 )
replace CF17 = . if (CF17 <= -1 )
replace CF17_A = . if (CF17_A <= -1 )
replace CF17_B = . if (CF17_B <= -1 )
replace CF18 = . if (CF18 <= -1 )
replace CF19 = . if (CF19 <= -1 )
replace CF20 = . if (CF20 <= -1 )
replace CF21 = . if (CF21 <= -1 )
replace CF21_A = . if (CF21_A <= -1 )
replace CF21_B = . if (CF21_B <= -1 )
replace CF21_C = . if (CF21_C <= -1 )
replace CF21_D = . if (CF21_D <= -1 )
replace CF21_E = . if (CF21_E <= -1 )
replace CF21_F = . if (CF21_F <= -1 )
replace CF21_G = . if (CF21_G <= -1 )
replace CF21_H = . if (CF21_H <= -1 )
replace CF21_I = . if (CF21_I <= -1 )
replace CF22 = . if (CF22 <= -1 )
replace CF22_A = . if (CF22_A <= -1 )
replace CF22_B = . if (CF22_B <= -1 )
replace CF22_C = . if (CF22_C <= -1 )
replace CF22_D = . if (CF22_D <= -1 )
replace CF22_E = . if (CF22_E <= -1 )
replace CF22_F = . if (CF22_F <= -1 )
replace CF22_G = . if (CF22_G <= -1 )
replace CF22_H = . if (CF22_H <= -1 )
replace CF22_I = . if (CF22_I <= -1 )
replace CF23 = . if (CF23 <= -1 )
replace CF23_A = . if (CF23_A <= -1 )
replace CF23_B = . if (CF23_B <= -1 )
replace CF23_C = . if (CF23_C <= -1 )
replace CF23_D = . if (CF23_D <= -1 )
replace CF23_E = . if (CF23_E <= -1 )
replace CF23_F = . if (CF23_F <= -1 )
replace CF23_G = . if (CF23_G <= -1 )
replace CF23_H = . if (CF23_H <= -1 )
replace CF23_I = . if (CF23_I <= -1 )
replace CF24 = . if (CF24 <= -1 )
replace CF25 = . if (CF25 <= -1 )
replace CF26 = . if (CF26 <= -1 )
replace CF27 = . if (CF27 <= -1 )
replace CF27A_M = . if (CF27A_M <= -1 )
replace CF27_A_1 = . if (CF27_A_1 <= -1 )
replace CF27B_M = . if (CF27B_M <= -1 )
replace CF27_B_1 = . if (CF27_B_1 <= -1 )
replace CF28 = . if (CF28 <= -1 )
replace CF29 = . if (CF29 <= -1 )
replace CF30 = . if (CF30 <= -1 )
replace CF30_A = . if (CF30_A <= -1 )
replace CF30_B = . if (CF30_B <= -1 )
replace CF30C_M = . if (CF30C_M <= -1 )
replace CF30_C_1 = . if (CF30_C_1 <= -1 )
replace CF30D_M = . if (CF30D_M <= -1 )
replace CF30_D_1 = . if (CF30_D_1 <= -1 )
replace CF31 = . if (CF31 <= -1 )
replace CF31_A = . if (CF31_A <= -1 )
replace CF31_B = . if (CF31_B <= -1 )
replace CF31C_M = . if (CF31C_M <= -1 )
replace CF31_C_1 = . if (CF31_C_1 <= -1 )
replace CF31D_M = . if (CF31D_M <= -1 )
replace CF31_D_1 = . if (CF31_D_1 <= -1 )
replace CF32_WKS = . if (CF32_WKS <= -1 )
replace CF33_M = . if (CF33_M <= -1 )
replace CF33_1 = . if (CF33_1 <= -1 )
replace CF33A_M = . if (CF33A_M <= -1 )
replace CF33_A_1 = . if (CF33_A_1 <= -1 )
replace CF33_B = . if (CF33_B <= -1 )
replace CF34 = . if (CF34 <= -1 )
replace CF34_A = . if (CF34_A <= -1 )
replace CF35 = . if (CF35 <= -1 )
replace CF36 = . if (CF36 <= -1 )
replace CF36_A = . if (CF36_A <= -1 )
replace CF36_B = . if (CF36_B <= -1 )
replace CF36_C = . if (CF36_C <= -1 )
replace CF36_D = . if (CF36_D <= -1 )
replace CF37 = . if (CF37 <= -1 )
replace CF37_A = . if (CF37_A <= -1 )
replace CF37_B = . if (CF37_B <= -1 )
replace CF38 = . if (CF38 <= -1 )
replace CF39 = . if (CF39 <= -1 )
replace CF40 = . if (CF40 <= -1 )
replace CF41_3 = . if (CF41_3 <= -1 )
replace CF41_4 = . if (CF41_4 <= -1 )
replace CF41_5 = . if (CF41_5 <= -1 )
replace CF41_6 = . if (CF41_6 <= -1 )
replace CF41_7 = . if (CF41_7 <= -1 )
replace CF41_8 = . if (CF41_8 <= -1 )
replace CF41_9 = . if (CF41_9 <= -1 )
replace CF41_10 = . if (CF41_10 <= -1 )
replace CF41_11 = . if (CF41_11 <= -1 )
replace CF41_12 = . if (CF41_12 <= -1 )
replace CF41_13 = . if (CF41_13 <= -1 )
replace CF41_14 = . if (CF41_14 <= -1 )
replace CF41_15 = . if (CF41_15 <= -1 )
replace CF41_16 = . if (CF41_16 <= -1 )
replace CF41_17 = . if (CF41_17 <= -1 )
replace CF41_17A = . if (CF41_17A <= -1 )
replace CF41_17B = . if (CF41_17B <= -1 )
replace CF41_19 = . if (CF41_19 <= -1 )
replace CF41_20 = . if (CF41_20 <= -1 )
replace CF41_21 = . if (CF41_21 <= -1 )
replace CF41_22 = . if (CF41_22 <= -1 )
replace CF41_23 = . if (CF41_23 <= -1 )
replace CF41_24 = . if (CF41_24 <= -1 )
replace CF41_25 = . if (CF41_25 <= -1 )
replace CF41_26 = . if (CF41_26 <= -1 )
replace CF41_27 = . if (CF41_27 <= -1 )
replace CG1 = . if (CG1 <= -1 )
replace CG2 = . if (CG2 <= -1 )
replace CG3 = . if (CG3 <= -1 )
replace CG3_A = . if (CG3_A <= -1 )
replace CG3_B = . if (CG3_B <= -1 )
replace CG4 = . if (CG4 <= -1 )
replace CG5 = . if (CG5 <= -1 )
replace CG6 = . if (CG6 <= -1 )
replace CG6_A = . if (CG6_A <= -1 )
replace CG6B_M = . if (CG6B_M <= -1 )
replace CG6_B_1 = . if (CG6_B_1 <= -1 )
replace CG6C_M = . if (CG6C_M <= -1 )
replace CG6_C_1 = . if (CG6_C_1 <= -1 )
replace CG6_D = . if (CG6_D <= -1 )
replace CG7 = . if (CG7 <= -1 )
replace CG7_A = . if (CG7_A <= -1 )
replace CG8 = . if (CG8 <= -1 )
replace CG8_A = . if (CG8_A <= -1 )
replace CG9 = . if (CG9 <= -1 )
replace CG14 = . if (CG14 <= -1 )
replace CG10 = . if (CG10 <= -1 )
replace CG11 = . if (CG11 <= -1 )
replace CG11_A = . if (CG11_A <= -1 )
replace CG12 = . if (CG12 <= -1 )
replace CG13 = . if (CG13 <= -1 )
replace CG15 = . if (CG15 <= -1 )
replace CG15_A = . if (CG15_A <= -1 )
replace CG16 = . if (CG16 <= -1 )
replace CG16_A = . if (CG16_A <= -1 )
replace CG17 = . if (CG17 <= -1 )
replace CG17_A = . if (CG17_A <= -1 )
replace CG18 = . if (CG18 <= -1 )
replace CG19 = . if (CG19 <= -1 )
replace CG20 = . if (CG20 <= -1 )
replace CG21 = . if (CG21 <= -1 )
replace CG22 = . if (CG22 <= -1 )
replace CG22_A = . if (CG22_A <= -1 )
replace CH1 = . if (CH1 <= -1 )
replace CH2 = . if (CH2 <= -1 )
replace CH3 = . if (CH3 <= -1 )
replace CH3_A = . if (CH3_A <= -1 )
replace CH4 = . if (CH4 <= -1 )
replace CH4_A = . if (CH4_A <= -1 )
replace CH5 = . if (CH5 <= -1 )
replace CH5_A = . if (CH5_A <= -1 )
replace CH6 = . if (CH6 <= -1 )
replace CH6_A = . if (CH6_A <= -1 )
replace CH7 = . if (CH7 <= -1 )
replace CH7_A = . if (CH7_A <= -1 )
replace CH8 = . if (CH8 <= -1 )
replace CH8_A = . if (CH8_A <= -1 )
replace CH9 = . if (CH9 <= -1 )
replace CH9_A = . if (CH9_A <= -1 )
replace CH10 = . if (CH10 <= -1 )
replace CH10_A = . if (CH10_A <= -1 )
replace CH10_B = . if (CH10_B <= -1 )
replace CH11 = . if (CH11 <= -1 )
replace CH11_A = . if (CH11_A <= -1 )
replace CH12 = . if (CH12 <= -1 )
replace CH12_A = . if (CH12_A <= -1 )
replace CH13 = . if (CH13 <= -1 )
replace CH13_A = . if (CH13_A <= -1 )
replace CH14 = . if (CH14 <= -1 )
replace CH14_A = . if (CH14_A <= -1 )
replace CH15 = . if (CH15 <= -1 )
replace CH15_A = . if (CH15_A <= -1 )
replace CH16 = . if (CH16 <= -1 )
replace CH17 = . if (CH17 <= -1 )
replace CH18 = . if (CH18 <= -1 )
replace CH18_A = . if (CH18_A <= -1 )
replace CH19 = . if (CH19 <= -1 )
replace CH19_A = . if (CH19_A <= -1 )
replace CH19_B = . if (CH19_B <= -1 )
replace CH20 = . if (CH20 <= -1 )
replace CH20_A = . if (CH20_A <= -1 )
replace CH21 = . if (CH21 <= -1 )
replace CH22 = . if (CH22 <= -1 )
replace CH23 = . if (CH23 <= -1 )
replace CH24 = . if (CH24 <= -1 )
replace CH25 = . if (CH25 <= -1 )
replace CH26_M = . if (CH26_M <= -1 )
replace CH26_1 = . if (CH26_1 <= -1 )
replace CH26A_M = . if (CH26A_M <= -1 )
replace CH26_A_1 = . if (CH26_A_1 <= -1 )
replace CH26_B = . if (CH26_B <= -1 )
replace CH27 = . if (CH27 <= -1 )
replace CH28 = . if (CH28 <= -1 )
replace CH29 = . if (CH29 <= -1 )
replace CH30 = . if (CH30 <= -1 )
replace CJ1_A = . if (CJ1_A <= -1 )
replace CJ1_B = . if (CJ1_B <= -1 )
replace CJ1_C = . if (CJ1_C <= -1 )
replace CJ1_D = . if (CJ1_D <= -1 )
replace CJ1_E = . if (CJ1_E <= -1 )
replace CJ1_F = . if (CJ1_F <= -1 )
replace CJ1_G = . if (CJ1_G <= -1 )
replace CJ1_H = . if (CJ1_H <= -1 )
replace CJ1_I = . if (CJ1_I <= -1 )
replace CJ1_J = . if (CJ1_J <= -1 )
replace CJ2 = . if (CJ2 <= -1 )
replace CJ3_A = . if (CJ3_A <= -1 )
replace CJ3_B = . if (CJ3_B <= -1 )
replace CJ3_C = . if (CJ3_C <= -1 )
replace CJ3_D = . if (CJ3_D <= -1 )
replace CJ3_E = . if (CJ3_E <= -1 )
replace CJ3_F = . if (CJ3_F <= -1 )
replace CJ3_G = . if (CJ3_G <= -1 )
replace CJ3_H = . if (CJ3_H <= -1 )
replace CJ3_I = . if (CJ3_I <= -1 )
replace CJ3_J = . if (CJ3_J <= -1 )
replace CJ3_K = . if (CJ3_K <= -1 )
replace CJ3_L = . if (CJ3_L <= -1 )
replace CJ3_M = . if (CJ3_M <= -1 )
replace CJ3_N = . if (CJ3_N <= -1 )
replace CJ4 = . if (CJ4 <= -1 )
replace CJ5_A = . if (CJ5_A <= -1 )
replace CJ5_B = . if (CJ5_B <= -1 )
replace CJ5_C = . if (CJ5_C <= -1 )
replace CJ5_D = . if (CJ5_D <= -1 )
replace CJ5_E = . if (CJ5_E <= -1 )
replace CJ5_F = . if (CJ5_F <= -1 )
replace CJ6 = . if (CJ6 <= -1 )
replace CJ7_A = . if (CJ7_A <= -1 )
replace CJ7_B = . if (CJ7_B <= -1 )
replace CJ7_C = . if (CJ7_C <= -1 )
replace CJ7_D = . if (CJ7_D <= -1 )
replace CJ7_E = . if (CJ7_E <= -1 )
replace CJ7_F = . if (CJ7_F <= -1 )
replace CJ7_G = . if (CJ7_G <= -1 )
replace CK1 = . if (CK1 <= -1 )
replace CK2 = . if (CK2 <= -1 )
replace CK3 = . if (CK3 <= -1 )
replace CK4 = . if (CK4 <= -1 )
replace CK5 = . if (CK5 <= -1 )
replace CK6 = . if (CK6 <= -1 )
replace CK7 = . if (CK7 <= -1 )
replace CK8 = . if (CK8 <= -1 )
replace CK9 = . if (CK9 <= -1 )
replace CK10 = . if (CK10 <= -1 )
replace CK11 = . if (CK11 <= -1 )
replace CK12 = . if (CK12 <= -1 )
replace CK13 = . if (CK13 <= -1 )
replace CK14 = . if (CK14 <= -1 )
replace CK15 = . if (CK15 <= -1 )
replace CK16 = . if (CK16 <= -1 )
replace CK17 = . if (CK17 <= -1 )
replace CK18 = . if (CK18 <= -1 )
replace CK19 = . if (CK19 <= -1 )
replace CK20 = . if (CK20 <= -1 )
replace CL1 = . if (CL1 <= -1 )
replace CL2 = . if (CL2 <= -1 )
replace CL3 = . if (CL3 <= -1 )
replace CL4 = . if (CL4 <= -1 )
replace CL5 = . if (CL5 <= -1 )
replace CL6 = . if (CL6 <= -1 )
replace CL7_1 = . if (CL7_1 <= -1 )
replace CL7_2 = . if (CL7_2 <= -1 )
replace CL7_6 = . if (CL7_6 <= -1 )
replace CL7_6_B = . if (CL7_6_B <= -1 )
replace CL7_7 = . if (CL7_7 <= -1 )
replace CL7_8 = . if (CL7_8 <= -1 )
replace CL7_8_B = . if (CL7_8_B <= -1 )
replace CL8 = . if (CL8 <= -1 )
replace CL9 = . if (CL9 <= -1 )
replace CL9_A = . if (CL9_A <= -1 )
replace CL10_1 = . if (CL10_1 <= -1 )
replace CL10_1_1 = . if (CL10_1_1 <= -1 )
replace CL10_2 = . if (CL10_2 <= -1 )
replace CL10_2_1 = . if (CL10_2_1 <= -1 )
replace CL10_3 = . if (CL10_3 <= -1 )
replace CL10_3_1 = . if (CL10_3_1 <= -1 )
replace CL10_4 = . if (CL10_4 <= -1 )
replace CL10_4_1 = . if (CL10_4_1 <= -1 )
replace CL11 = . if (CL11 <= -1 )
replace CL11_A_1 = . if (CL11_A_1 <= -1 )
replace CL11_A_2 = . if (CL11_A_2 <= -1 )
replace CL11_A_3 = . if (CL11_A_3 <= -1 )
replace CL11_A_4 = . if (CL11_A_4 <= -1 )
replace CL11_A_5 = . if (CL11_A_5 <= -1 )
replace CL11_A_6 = . if (CL11_A_6 <= -1 )
replace CL12 = . if (CL12 <= -1 )
replace CL13 = . if (CL13 <= -1 )
replace CL13_A_H = . if (CL13_A_H <= -1 )
replace CL13_A_M = . if (CL13_A_M <= -1 )
replace CL14 = . if (CL14 <= -1 )
replace CM1 = . if (CM1 <= -1 )
replace CM2 = . if (CM2 <= -1 )
replace CM3 = . if (CM3 <= -1 )
replace CM4 = . if (CM4 <= -1 )
replace CM5 = . if (CM5 <= -1 )
replace CM6 = . if (CM6 <= -1 )
replace CM7 = . if (CM7 <= -1 )
replace CM8 = . if (CM8 <= -1 )
replace CM9 = . if (CM9 <= -1 )
replace CM10_A = . if (CM10_A <= -1 )
replace CM10_B = . if (CM10_B <= -1 )
replace CM11_A = . if (CM11_A <= -1 )
replace CM11_B = . if (CM11_B <= -1 )
replace CM11_C = . if (CM11_C <= -1 )
replace CM12_A = . if (CM12_A <= -1 )
replace CM12_B = . if (CM12_B <= -1 )
replace CM12_C = . if (CM12_C <= -1 )
replace CM12_D = . if (CM12_D <= -1 )
replace CM12_E = . if (CM12_E <= -1 )
replace CM13 = . if (CM13 <= -1 )
replace CM14_A = . if (CM14_A <= -1 )
replace CM14_B = . if (CM14_B <= -1 )
replace CM14_C = . if (CM14_C <= -1 )
replace CM15_A = . if (CM15_A <= -1 )
replace CM15_B = . if (CM15_B <= -1 )
replace CM16 = . if (CM16 <= -1 )
replace CM17 = . if (CM17 <= -1 )
replace CM18_A = . if (CM18_A <= -1 )
replace CM18_B = . if (CM18_B <= -1 )
replace CM18_C = . if (CM18_C <= -1 )
replace CM19 = . if (CM19 <= -1 )
replace CM20 = . if (CM20 <= -1 )
replace CM21 = . if (CM21 <= -1 )
replace FTWORK = . if (FTWORK <= -1 )
replace MSTAT = . if (MSTAT <= -1 )
replace AGE = . if (AGE <= -1 )
replace AGEGRP = . if (AGEGRP <= -1 )
replace EDLEV = . if (EDLEV <= -1 )
replace CJ_STAT = . if (CJ_STAT <= -1 )
replace HLTHINS = . if (HLTHINS <= -1 )
replace MAJSRC = . if (MAJSRC <= -1 )
replace REFER = . if (REFER <= -1 )
replace RESTRICT = . if (RESTRICT <= -1 )
replace PDRUG = . if (PDRUG <= -1 )
replace PDRUGFRQ = . if (PDRUGFRQ <= -1 )
replace FAVDRUG = . if (FAVDRUG <= -1 )
replace HVY_ALC = . if (HVY_ALC <= -1 )
replace ALCWK = . if (ALCWK <= -1 )
replace MRJWK = . if (MRJWK <= -1 )
replace COCWK = . if (COCWK <= -1 )
replace CRKWK = . if (CRKWK <= -1 )
replace HERWK = . if (HERWK <= -1 )
replace NARWK = . if (NARWK <= -1 )
replace SEDWK = . if (SEDWK <= -1 )
replace AMPWK = . if (AMPWK <= -1 )
replace HALWK = . if (HALWK <= -1 )
replace INHWK = . if (INHWK <= -1 )
replace HERHX = . if (HERHX <= -1 )
replace COCHX = . if (COCHX <= -1 )
replace DRUGTX = . if (DRUGTX <= -1 )
replace DRGTXAGE = . if (DRGTXAGE <= -1 )
replace MRTX1 = . if (MRTX1 <= -1 )
replace MRTX2 = . if (MRTX2 <= -1 )
replace MRTX3 = . if (MRTX3 <= -1 )
replace MRTX4 = . if (MRTX4 <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

